--[[
Copyright (C) 2016-2017  Neemys

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

See <LICENSE.txt> for a copy of this license, or see <http://www.gnu.org/licenses/>
]]


-- get platform base tile object, copy concrete if possible.
local buildingPlatformTile
--don't copy concrete in 0.16
if(data.raw["tile"]["concrete"] and 1==2 ) then --copy actual concrete data if accessible
	buildingPlatformTile = table.deepcopy(data.raw["tile"]["concrete"])
else --last concrete tile info check in version 0.15.35
	buildingPlatformTile = {
      type = "tile",
      name = "concrete",
      needs_correction = false,
      minable = {hardness = 0.2, mining_time = 0.5, result = "concrete"},
      mined_sound = { filename = "__base__/sound/deconstruct-bricks.ogg" },
      collision_mask = {"ground-tile"},
      walking_speed_modifier = 1.4,
      layer = 61,
      decorative_removal_probability = 0.25,
      variants =
      {
        main =
        {
          {
            picture = "__base__/graphics/terrain/concrete/concrete1.png",
            count = 16,
            size = 1
          },
          {
            picture = "__base__/graphics/terrain/concrete/concrete2.png",
            count = 4,
            size = 2,
            probability = 0.39,
          },
          {
            picture = "__base__/graphics/terrain/concrete/concrete4.png",
            count = 4,
            size = 4,
            probability = 1,
          },
        },
        inner_corner =
        {
          picture = "__base__/graphics/terrain/concrete/concrete-inner-corner.png",
          count = 32
        },
        outer_corner =
        {
          picture = "__base__/graphics/terrain/concrete/concrete-outer-corner.png",
          count = 16
        },
        side =
        {
          picture = "__base__/graphics/terrain/concrete/concrete-side.png",
          count = 16
        },
        u_transition =
        {
          picture = "__base__/graphics/terrain/concrete/concrete-u.png",
          count = 16
        },
        o_transition =
        {
          picture = "__base__/graphics/terrain/concrete/concrete-o.png",
          count = 1
        }
      },
      walking_sound =
      {
        {
          filename = "__base__/sound/walking/concrete-01.ogg",
          volume = 1.2
        },
        {
          filename = "__base__/sound/walking/concrete-02.ogg",
          volume = 1.2
        },
        {
          filename = "__base__/sound/walking/concrete-03.ogg",
          volume = 1.2
        },
        {
          filename = "__base__/sound/walking/concrete-04.ogg",
          volume = 1.2
        }
      },
      map_color={r=100, g=100, b=100},
      ageing=0,
      vehicle_friction_modifier = concrete_vehicle_speed_modifier
    }
end



--then for all tile that need to be created, copy the base tile and edit what's needed
for _,platformDefinition in pairs(buildingplatform.tiles) do
	local tile = table.deepcopy(buildingPlatformTile)
	tile.can_be_part_of_blueprint = false

	tile.variants.main[1].picture = platformDefinition.picturesDirectory.."/"..platformDefinition.name.."1.png"
	tile.variants.main[2].picture = platformDefinition.picturesDirectory.."/"..platformDefinition.name.."2.png"
	tile.variants.main[3].picture = platformDefinition.picturesDirectory.."/"..platformDefinition.name.."4.png"
	tile.variants.inner_corner.picture = platformDefinition.picturesDirectory.."/"..platformDefinition.name.."-inner-corner.png"
	tile.variants.inner_corner.count = 8
	tile.variants.outer_corner.picture = platformDefinition.picturesDirectory.."/"..platformDefinition.name.."-outer-corner.png"
	tile.variants.outer_corner.count = 8
	tile.variants.side.picture = platformDefinition.picturesDirectory.."/"..platformDefinition.name.."-side.png"
	tile.variants.side.count = 8
	tile.variants.u_transition.picture = platformDefinition.picturesDirectory.."/"..platformDefinition.name.."-u.png"
	tile.variants.u_transition.count = 8
	tile.variants.o_transition.picture = platformDefinition.picturesDirectory.."/"..platformDefinition.name.."-o.png"

	tile.map_color = platformDefinition.mapColor
	tile.minable = nil --needed to be able to place other tile over it
	tile.autoplace = platformDefinition.autoplaceObject
	platformDefinition.tileFunction(tile)
	tile.name = platformDefinition.name --after the function, so the given function don't rename the tile as it will likely generate an error in later step
	data:extend({tile})
end
